# pylint: disable=no-member,wrong-import-position,no-name-in-module
import json
from typing import Union

import jsonschema

from instill.clients import InstillClient
from instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 import Component
from instill.resources import const
from instill.resources.connector import Connector
from instill.resources.schema import (
    bigquery,
    bigquery_task_insert_input,
    googlecloudstorage,
    googlecloudstorage_task_upload_input,
    googlesearch,
    googlesearch_task_search_input,
    helper,
    pinecone,
    pinecone_task_query_input,
    pinecone_task_upsert_input,
    redis,
    redis_task_chat_history_retrieve_input,
    redis_task_chat_message_write_input,
    redis_task_chat_message_write_multi_modal_input,
    restapi,
    restapi_task_delete_input,
    restapi_task_get_input,
    restapi_task_head_input,
    restapi_task_options_input,
    restapi_task_patch_input,
    restapi_task_post_input,
    restapi_task_put_input,
    website,
    website_task_scrape_website_input,
)


class BigQueryConnector(Connector):
    """BigQuery Connector"""

    with open(
        f"{const.SPEC_PATH}/bigquery_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: bigquery.BigQueryConnectorSpec,
    ) -> None:
        definition = "connector-definitions/bigquery"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, BigQueryConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: bigquery_task_insert_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class PineconeConnector(Connector):
    """Pinecone Connector"""

    with open(
        f"{const.SPEC_PATH}/pinecone_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: pinecone.PineconeConnectorSpec,
    ) -> None:
        definition = "connector-definitions/pinecone"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, PineconeConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: Union[
            pinecone_task_query_input.Input,
            pinecone_task_upsert_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class GoogleCloudStorageConnector(Connector):
    """GoogleCloudStorage Connector"""

    with open(
        f"{const.SPEC_PATH}/googlecloudstorage_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: googlecloudstorage.GoogleCloudStorageConnectorSpec,
    ) -> None:
        definition = "connector-definitions/gcs"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(
            config_spec, GoogleCloudStorageConnector.definitions_jsonschema
        )
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: googlecloudstorage_task_upload_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class GoogleSearchConnector(Connector):
    """GoogleSearch Connector"""

    with open(
        f"{const.SPEC_PATH}/googlecloudstorage_definitions.json", "r", encoding="utf8"
    ) as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: googlesearch.GoogleSearchConnectorSpec,
    ) -> None:
        definition = "connector-definitions/google-search"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, GoogleSearchConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: googlesearch_task_search_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class RedisConnector(Connector):
    """Redis Connector"""

    with open(f"{const.SPEC_PATH}/redis_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: redis.RedisConnectorResource,
    ) -> None:
        definition = "connector-definitions/redis"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, RedisConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: Union[
            redis_task_chat_history_retrieve_input.Input,
            redis_task_chat_message_write_input.Input,
            redis_task_chat_message_write_multi_modal_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class RestAPIConnector(Connector):
    """RestAPI Connector"""

    with open(f"{const.SPEC_PATH}/restapi_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: restapi.RESTAPIConnectorSpec,
    ) -> None:
        definition = "connector-definitions/restapi"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, RestAPIConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: Union[
            restapi_task_delete_input.Input,
            restapi_task_options_input.Input,
            restapi_task_get_input.InputWithoutBody,
            restapi_task_head_input.InputWithoutBody,
            restapi_task_patch_input.Input,
            restapi_task_post_input.Input,
            restapi_task_patch_input.Input,
            restapi_task_put_input.Input,
        ],
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)


class WebsiteConnector(Connector):
    """Website Connector"""

    with open(f"{const.SPEC_PATH}/website_definitions.json", "r", encoding="utf8") as f:
        definitions_jsonschema = json.loads(f.read())

    def __init__(
        self,
        client: InstillClient,
        name: str,
        config: website.WebsiteConnectorResource,
    ) -> None:
        definition = "connector-definitions/website"

        config_spec = helper.pop_default_and_to_dict(config)
        jsonschema.validate(config_spec, WebsiteConnector.definitions_jsonschema)
        super().__init__(client, name, definition, config_spec)

    def create_component(
        self,
        name: str,
        inp: website_task_scrape_website_input.Input,
    ) -> Component:
        config = helper.construct_component_config(inp)
        return super()._create_component(name, config)



# generated by datamodel-codegen:
#   filename:  json_task_unmarshal_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Output:
    object: Dict[str, Any]



# generated by datamodel-codegen:
#   filename:  restapi_task_delete_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Dict


@dataclass
class Output:
    body: Dict[str, Any]
    header: Dict[str, Any]
    status_code: int



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/controller/v1alpha/controller_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from model.controller.v1alpha import controller_pb2 as model_dot_controller_dot_v1alpha_dot_controller__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1model/controller/v1alpha/controller_service.proto\x12\x18model.controller.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a)model/controller/v1alpha/controller.proto2\x97\x07\n\x18\x43ontrollerPrivateService\x12\x9c\x01\n\x08Liveness\x12).model.controller.v1alpha.LivenessRequest\x1a*.model.controller.v1alpha.LivenessResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x13/v1alpha/__livenessZ\x1c\x12\x1a/v1alpha/health/controller\x12\x82\x01\n\tReadiness\x12*.model.controller.v1alpha.ReadinessRequest\x1a+.model.controller.v1alpha.ReadinessResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1alpha/__readiness\x12\xba\x01\n\x0bGetResource\x12,.model.controller.v1alpha.GetResourceRequest\x1a-.model.controller.v1alpha.GetResourceResponse\"N\xda\x41\x12resource_permalink\x82\xd3\xe4\x93\x02\x33\x12\x31/v1alpha/{resource_permalink=resources/*/types/*}\x12\xc1\x01\n\x0eUpdateResource\x12/.model.controller.v1alpha.UpdateResourceRequest\x1a\x30.model.controller.v1alpha.UpdateResourceResponse\"L\x82\xd3\xe4\x93\x02\x46\x32:/v1alpha/{resource.resource_permalink=resources/*/types/*}:\x08resource\x12\xc3\x01\n\x0e\x44\x65leteResource\x12/.model.controller.v1alpha.DeleteResourceRequest\x1a\x30.model.controller.v1alpha.DeleteResourceResponse\"N\xda\x41\x12resource_permalink\x82\xd3\xe4\x93\x02\x33*1/v1alpha/{resource_permalink=resources/*/types/*}\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\x86\x02\n\x1c\x63om.model.controller.v1alphaB\x16\x43ontrollerServiceProtoP\x01ZLgithub.com/instill-ai/protogen-go/model/controller/v1alpha;controllerv1alpha\xa2\x02\x03MCX\xaa\x02\x18Model.Controller.V1alpha\xca\x02\x18Model\\Controller\\V1alpha\xe2\x02$Model\\Controller\\V1alpha\\GPBMetadata\xea\x02\x1aModel::Controller::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.controller.v1alpha.controller_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.model.controller.v1alphaB\026ControllerServiceProtoP\001ZLgithub.com/instill-ai/protogen-go/model/controller/v1alpha;controllerv1alpha\242\002\003MCX\252\002\030Model.Controller.V1alpha\312\002\030Model\\Controller\\V1alpha\342\002$Model\\Controller\\V1alpha\\GPBMetadata\352\002\032Model::Controller::V1alpha'
  _CONTROLLERPRIVATESERVICE._options = None
  _CONTROLLERPRIVATESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _CONTROLLERPRIVATESERVICE.methods_by_name['Liveness']._options = None
  _CONTROLLERPRIVATESERVICE.methods_by_name['Liveness']._serialized_options = b'\202\323\344\223\0023\022\023/v1alpha/__livenessZ\034\022\032/v1alpha/health/controller'
  _CONTROLLERPRIVATESERVICE.methods_by_name['Readiness']._options = None
  _CONTROLLERPRIVATESERVICE.methods_by_name['Readiness']._serialized_options = b'\202\323\344\223\002\026\022\024/v1alpha/__readiness'
  _CONTROLLERPRIVATESERVICE.methods_by_name['GetResource']._options = None
  _CONTROLLERPRIVATESERVICE.methods_by_name['GetResource']._serialized_options = b'\332A\022resource_permalink\202\323\344\223\0023\0221/v1alpha/{resource_permalink=resources/*/types/*}'
  _CONTROLLERPRIVATESERVICE.methods_by_name['UpdateResource']._options = None
  _CONTROLLERPRIVATESERVICE.methods_by_name['UpdateResource']._serialized_options = b'\202\323\344\223\002F2:/v1alpha/{resource.resource_permalink=resources/*/types/*}:\010resource'
  _CONTROLLERPRIVATESERVICE.methods_by_name['DeleteResource']._options = None
  _CONTROLLERPRIVATESERVICE.methods_by_name['DeleteResource']._serialized_options = b'\332A\022resource_permalink\202\323\344\223\0023*1/v1alpha/{resource_permalink=resources/*/types/*}'
  _globals['_CONTROLLERPRIVATESERVICE']._serialized_start=207
  _globals['_CONTROLLERPRIVATESERVICE']._serialized_end=1126
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7artifact/artifact/v1alpha/artifact_public_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\x98\x03\n\x15\x41rtifactPublicService\x12\xac\x01\n\x08Liveness\x12*.artifact.artifact.v1alpha.LivenessRequest\x1a+.artifact.artifact.v1alpha.LivenessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x13/v1alpha/__livenessZ\x1a\x12\x18/v1alpha/health/artifact\x12\xaf\x01\n\tReadiness\x12+.artifact.artifact.v1alpha.ReadinessRequest\x1a,.artifact.artifact.v1alpha.ReadinessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x14/v1alpha/__readinessZ\x19\x12\x17/v1alpha/ready/artifact\x1a\x1e\x92\x41\x1b\x12\x19Public Artifact endpointsB\x8e\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1a\x41rtifactPublicServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\032ArtifactPublicServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _ARTIFACTPUBLICSERVICE._options = None
  _ARTIFACTPUBLICSERVICE._serialized_options = b'\222A\033\022\031Public Artifact endpoints'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\023/v1alpha/__livenessZ\032\022\030/v1alpha/health/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\024/v1alpha/__readinessZ\031\022\027/v1alpha/ready/artifact'
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_start=236
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_end=644
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  instill_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Any, Optional, Union


@dataclass
class InstillModelConnectorInternalMode:
    mode: Optional[Any] = None


@dataclass
class InstillModelConnectorExternalMode:
    api_token: str
    server_url: str
    mode: Optional[Any] = None


InstillModelConnector = Union[
    InstillModelConnectorInternalMode, InstillModelConnectorExternalMode
]



# generated by datamodel-codegen:
#   filename:  googlesearch_definitions.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class GoogleSearchConnectorSpec:
    api_key: str
    cse_id: str



# generated by datamodel-codegen:
#   filename:  huggingface_task_audio_classification_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Class:
    label: str
    score: float


@dataclass
class Output:
    classes: List[Class]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Mode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Mode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODE_UNSPECIFIED: _Mode.ValueType  # 0
    """Unspecified."""
    MODE_SYNC: _Mode.ValueType  # 1
    """Synchronous (result is returned in the response)."""
    MODE_ASYNC: _Mode.ValueType  # 2
    """Asynchronous (response only contains acknowledgement)."""

class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
    """Mode describes the execution mode of the pipeline (sync or async)."""

MODE_UNSPECIFIED: Mode.ValueType  # 0
"""Unspecified."""
MODE_SYNC: Mode.ValueType  # 1
"""Synchronous (result is returned in the response)."""
MODE_ASYNC: Mode.ValueType  # 2
"""Asynchronous (response only contains acknowledgement)."""
global___Mode = Mode

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """Unspecified."""
    STATUS_COMPLETED: _Status.ValueType  # 1
    """Successfully completed."""
    STATUS_ERRORED: _Status.ValueType  # 2
    """Finished with error."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper):
    """Status describes the output of an execution."""

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""Unspecified."""
STATUS_COMPLETED: Status.ValueType  # 1
"""Successfully completed."""
STATUS_ERRORED: Status.ValueType  # 2
"""Finished with error."""
global___Status = Status

@typing_extensions.final
class PipelineTriggerRecord(google.protobuf.message.Message):
    """========== Pipeline endpoints

    PipelineTriggerRecord represents a pipeline execution event.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGER_TIME_FIELD_NUMBER: builtins.int
    PIPELINE_TRIGGER_ID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    TRIGGER_MODE_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_DURATION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
    @property
    def trigger_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The moment when the pipeline was triggered."""
    pipeline_trigger_id: builtins.str
    """UUID of the trigger."""
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    trigger_mode: global___Mode.ValueType
    """Trigger mode."""
    compute_time_duration: builtins.float
    """Total execution duration."""
    status: global___Status.ValueType
    """Final status."""
    pipeline_release_id: builtins.str
    """If a release of the pipeline was triggered, pipeline version."""
    pipeline_release_uid: builtins.str
    """If a release of the pipeline was triggered, release UUID."""
    def __init__(
        self,
        *,
        trigger_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        pipeline_trigger_id: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        trigger_mode: global___Mode.ValueType = ...,
        compute_time_duration: builtins.float = ...,
        status: global___Status.ValueType = ...,
        pipeline_release_id: builtins.str = ...,
        pipeline_release_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["trigger_time", b"trigger_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_duration", b"compute_time_duration", "pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_trigger_id", b"pipeline_trigger_id", "pipeline_uid", b"pipeline_uid", "status", b"status", "trigger_mode", b"trigger_mode", "trigger_time", b"trigger_time"]) -> None: ...

global___PipelineTriggerRecord = PipelineTriggerRecord

@typing_extensions.final
class PipelineTriggerTableRecord(google.protobuf.message.Message):
    """PipelineTriggerTableRecord contains pipeline trigger metrics, aggregated by
    pipeline ID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    TRIGGER_COUNT_COMPLETED_FIELD_NUMBER: builtins.int
    TRIGGER_COUNT_ERRORED_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    trigger_count_completed: builtins.int
    """Number of triggers with `STATUS_COMPLETED`."""
    trigger_count_errored: builtins.int
    """Number of triggers with `STATUS_ERRORED`."""
    pipeline_release_id: builtins.str
    """Version for the triggered pipeline if it is a release pipeline."""
    pipeline_release_uid: builtins.str
    """Release UUID for the triggered pipeline if it is a release pipeline."""
    def __init__(
        self,
        *,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        trigger_count_completed: builtins.int = ...,
        trigger_count_errored: builtins.int = ...,
        pipeline_release_id: builtins.str = ...,
        pipeline_release_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_uid", b"pipeline_uid", "trigger_count_completed", b"trigger_count_completed", "trigger_count_errored", b"trigger_count_errored"]) -> None: ...

global___PipelineTriggerTableRecord = PipelineTriggerTableRecord

@typing_extensions.final
class PipelineTriggerChartRecord(google.protobuf.message.Message):
    """PipelineTriggerChartRecord contains pipeline trigger metrics, aggregated by
    pipeline ID and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    TRIGGER_MODE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TIME_BUCKETS_FIELD_NUMBER: builtins.int
    TRIGGER_COUNTS_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_DURATION_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_RELEASE_UID_FIELD_NUMBER: builtins.int
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    trigger_mode: global___Mode.ValueType
    """Trigger mode."""
    status: global___Status.ValueType
    """Final status."""
    @property
    def time_buckets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.timestamp_pb2.Timestamp]:
        """Time buckets."""
    @property
    def trigger_counts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Aggregated trigger count in each time bucket."""
    @property
    def compute_time_duration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Total computation time duration in each time bucket."""
    pipeline_release_id: builtins.str
    """Version for the triggered pipeline if it is a release pipeline."""
    pipeline_release_uid: builtins.str
    """Release UUID for the triggered pipeline if it is a release pipeline."""
    def __init__(
        self,
        *,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        trigger_mode: global___Mode.ValueType = ...,
        status: global___Status.ValueType = ...,
        time_buckets: collections.abc.Iterable[google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        trigger_counts: collections.abc.Iterable[builtins.int] | None = ...,
        compute_time_duration: collections.abc.Iterable[builtins.float] | None = ...,
        pipeline_release_id: builtins.str = ...,
        pipeline_release_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_duration", b"compute_time_duration", "pipeline_id", b"pipeline_id", "pipeline_release_id", b"pipeline_release_id", "pipeline_release_uid", b"pipeline_release_uid", "pipeline_uid", b"pipeline_uid", "status", b"status", "time_buckets", b"time_buckets", "trigger_counts", b"trigger_counts", "trigger_mode", b"trigger_mode"]) -> None: ...

global___PipelineTriggerChartRecord = PipelineTriggerChartRecord

@typing_extensions.final
class ListPipelineTriggerRecordsRequest(google.protobuf.message.Message):
    """ListPipelineTriggerRecordsRequest represents a request to list the triggers
    of a pipeline.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of triggers to return. If this parameter is unspecified,
    at most 100 pipelines will be returned. The cap value for this parameter is
    1000 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListPipelineTriggerRecordsRequest = ListPipelineTriggerRecordsRequest

@typing_extensions.final
class ListPipelineTriggerRecordsResponse(google.protobuf.message.Message):
    """ListPipelineTriggerRecordsResponse contains a list of pipeline triggers."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerRecord]:
        """A list of pipeline triggers."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline triggers."""
    def __init__(
        self,
        *,
        pipeline_trigger_records: collections.abc.Iterable[global___PipelineTriggerRecord] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipeline_trigger_records", b"pipeline_trigger_records", "total_size", b"total_size"]) -> None: ...

global___ListPipelineTriggerRecordsResponse = ListPipelineTriggerRecordsResponse

@typing_extensions.final
class ListPipelineTriggerTableRecordsRequest(google.protobuf.message.Message):
    """ListPipelineTriggerTableRecordsRequest represents a request to list the
    pipeline triggers metrics, aggregated by pipeline ID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results to return. If this parameter is unspecified,
    at most 100 pipelines will be returned. The cap value for this parameter
    is 1000 (i.e. any value above that will be coerced to 1000).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListPipelineTriggerTableRecordsRequest = ListPipelineTriggerTableRecordsRequest

@typing_extensions.final
class ListPipelineTriggerTableRecordsResponse(google.protobuf.message.Message):
    """ListPipelineTriggerTableRecordsResponse contains the pipeline metrics."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_TABLE_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_table_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerTableRecord]:
        """A list of pipeline trigger tables."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of pipeline trigger records"""
    def __init__(
        self,
        *,
        pipeline_trigger_table_records: collections.abc.Iterable[global___PipelineTriggerTableRecord] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipeline_trigger_table_records", b"pipeline_trigger_table_records", "total_size", b"total_size"]) -> None: ...

global___ListPipelineTriggerTableRecordsResponse = ListPipelineTriggerTableRecordsResponse

@typing_extensions.final
class ListPipelineTriggerChartRecordsRequest(google.protobuf.message.Message):
    """ListPipelineTriggerChartRecordsRequest represents a request to list pipeline
    trigger metrics, aggregated by pipeline ID and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_WINDOW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    aggregation_window: builtins.int
    """Aggregation window in nanoseconds."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        aggregation_window: builtins.int = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "aggregation_window", b"aggregation_window", "filter", b"filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...

global___ListPipelineTriggerChartRecordsRequest = ListPipelineTriggerChartRecordsRequest

@typing_extensions.final
class ListPipelineTriggerChartRecordsResponse(google.protobuf.message.Message):
    """ListPipelineTriggerChartRecordsResponse contains a list of pipeline trigger
    chart records.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_CHART_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_chart_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineTriggerChartRecord]:
        """A list of pipeline trigger records."""
    def __init__(
        self,
        *,
        pipeline_trigger_chart_records: collections.abc.Iterable[global___PipelineTriggerChartRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_trigger_chart_records", b"pipeline_trigger_chart_records"]) -> None: ...

global___ListPipelineTriggerChartRecordsResponse = ListPipelineTriggerChartRecordsResponse

@typing_extensions.final
class ConnectorExecuteRecord(google.protobuf.message.Message):
    """========== Connector endpoints

    ConnectorExecuteRecord represents a connector execution event.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTE_TIME_FIELD_NUMBER: builtins.int
    CONNECTOR_EXECUTE_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_UID_FIELD_NUMBER: builtins.int
    CONNECTOR_DEFINITION_UID_FIELD_NUMBER: builtins.int
    PIPELINE_ID_FIELD_NUMBER: builtins.int
    PIPELINE_UID_FIELD_NUMBER: builtins.int
    PIPELINE_TRIGGER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_DURATION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def execute_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The moment when the connector was executed."""
    connector_execute_id: builtins.str
    """UUID of the execution."""
    connector_id: builtins.str
    """Connector ID."""
    connector_uid: builtins.str
    """Connector UUID."""
    connector_definition_uid: builtins.str
    """Connector definition UUID."""
    pipeline_id: builtins.str
    """Pipeline ID."""
    pipeline_uid: builtins.str
    """Pipeline UUID."""
    pipeline_trigger_id: builtins.str
    """UUID of the pipeline trigger."""
    compute_time_duration: builtins.float
    """Total execution time."""
    status: global___Status.ValueType
    """Final status for the connector execution."""
    def __init__(
        self,
        *,
        execute_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        connector_execute_id: builtins.str = ...,
        connector_id: builtins.str = ...,
        connector_uid: builtins.str = ...,
        connector_definition_uid: builtins.str = ...,
        pipeline_id: builtins.str = ...,
        pipeline_uid: builtins.str = ...,
        pipeline_trigger_id: builtins.str = ...,
        compute_time_duration: builtins.float = ...,
        status: global___Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["execute_time", b"execute_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_duration", b"compute_time_duration", "connector_definition_uid", b"connector_definition_uid", "connector_execute_id", b"connector_execute_id", "connector_id", b"connector_id", "connector_uid", b"connector_uid", "execute_time", b"execute_time", "pipeline_id", b"pipeline_id", "pipeline_trigger_id", b"pipeline_trigger_id", "pipeline_uid", b"pipeline_uid", "status", b"status"]) -> None: ...

global___ConnectorExecuteRecord = ConnectorExecuteRecord

@typing_extensions.final
class ConnectorExecuteTableRecord(google.protobuf.message.Message):
    """ConnectorExecuteTableRecord contains connector execution metrics, a aggregated by connector ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_UID_FIELD_NUMBER: builtins.int
    EXECUTE_COUNT_COMPLETED_FIELD_NUMBER: builtins.int
    EXECUTE_COUNT_ERRORED_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """Connector ID."""
    connector_uid: builtins.str
    """Connector UUID."""
    execute_count_completed: builtins.int
    """Number of executions with `STATUS_COMPLETED`."""
    execute_count_errored: builtins.int
    """Number of executions with `STATUS_ERRORED`."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        connector_uid: builtins.str = ...,
        execute_count_completed: builtins.int = ...,
        execute_count_errored: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_id", b"connector_id", "connector_uid", b"connector_uid", "execute_count_completed", b"execute_count_completed", "execute_count_errored", b"execute_count_errored"]) -> None: ...

global___ConnectorExecuteTableRecord = ConnectorExecuteTableRecord

@typing_extensions.final
class ConnectorExecuteChartRecord(google.protobuf.message.Message):
    """ConnectorExecuteChartRecord contains connector execution metrics,
    agggregated by connector ID and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    CONNECTOR_UID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TIME_BUCKETS_FIELD_NUMBER: builtins.int
    EXECUTE_COUNTS_FIELD_NUMBER: builtins.int
    COMPUTE_TIME_DURATION_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """Connector ID."""
    connector_uid: builtins.str
    """Connector UUID."""
    status: global___Status.ValueType
    """Final status."""
    @property
    def time_buckets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.timestamp_pb2.Timestamp]:
        """Time buckets."""
    @property
    def execute_counts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Aggregated execution count in each time bucket."""
    @property
    def compute_time_duration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """Total computation time duration in each time bucket."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        connector_uid: builtins.str = ...,
        status: global___Status.ValueType = ...,
        time_buckets: collections.abc.Iterable[google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        execute_counts: collections.abc.Iterable[builtins.int] | None = ...,
        compute_time_duration: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_time_duration", b"compute_time_duration", "connector_id", b"connector_id", "connector_uid", b"connector_uid", "execute_counts", b"execute_counts", "status", b"status", "time_buckets", b"time_buckets"]) -> None: ...

global___ConnectorExecuteChartRecord = ConnectorExecuteChartRecord

@typing_extensions.final
class ListConnectorExecuteRecordsRequest(google.protobuf.message.Message):
    """ListConnectorExecuteRecordsRequest represents a request to list connector
    executions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of executions to return. If this parameter is
    unspecified, at most 100 pipelines will be returned. The cap value for
    this parameter is 1000 (i.e. any value above that will be coerced to
    1000).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListConnectorExecuteRecordsRequest = ListConnectorExecuteRecordsRequest

@typing_extensions.final
class ListConnectorExecuteRecordsResponse(google.protobuf.message.Message):
    """ListConnectorExecuteRecordsResponse represents a response for a list
    of connector execute record
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_EXECUTE_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connector_execute_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorExecuteRecord]:
        """A list of connector execute records"""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total count of connector execute records"""
    def __init__(
        self,
        *,
        connector_execute_records: collections.abc.Iterable[global___ConnectorExecuteRecord] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_execute_records", b"connector_execute_records", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorExecuteRecordsResponse = ListConnectorExecuteRecordsResponse

@typing_extensions.final
class ListConnectorExecuteTableRecordsRequest(google.protobuf.message.Message):
    """ListConnectorExecuteTableRecordsRequest represents a request to list the
    connector execution metrics, aggregated by connector.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results to return. If this parameter is unspecified,
    at most 100 pipelines will be returned. The cap value for this parameter
    is 1000 (i.e. any value above that will be coerced to 1000).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListConnectorExecuteTableRecordsRequest = ListConnectorExecuteTableRecordsRequest

@typing_extensions.final
class ListConnectorExecuteTableRecordsResponse(google.protobuf.message.Message):
    """ListConnectorExecuteTableRecordsResponse contains the connector metrics."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_EXECUTE_TABLE_RECORDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connector_execute_table_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorExecuteTableRecord]:
        """A list of connector execution records."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of connector execution records."""
    def __init__(
        self,
        *,
        connector_execute_table_records: collections.abc.Iterable[global___ConnectorExecuteTableRecord] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_execute_table_records", b"connector_execute_table_records", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorExecuteTableRecordsResponse = ListConnectorExecuteTableRecordsResponse

@typing_extensions.final
class ListConnectorExecuteChartRecordsRequest(google.protobuf.message.Message):
    """ListConnectorExecuteChartRecordsRequest represents a request to list
    connector execution metrics, aggregated by connector and time frame.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_WINDOW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    aggregation_window: builtins.int
    """Aggregation window in nanoseconds."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    def __init__(
        self,
        *,
        aggregation_window: builtins.int = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "aggregation_window", b"aggregation_window", "filter", b"filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...

global___ListConnectorExecuteChartRecordsRequest = ListConnectorExecuteChartRecordsRequest

@typing_extensions.final
class ListConnectorExecuteChartRecordsResponse(google.protobuf.message.Message):
    """ListConnectorExecuteChartRecordsResponse contains a list of connector
    execution chart records.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_EXECUTE_CHART_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def connector_execute_chart_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorExecuteChartRecord]:
        """A list of connector execution records."""
    def __init__(
        self,
        *,
        connector_execute_chart_records: collections.abc.Iterable[global___ConnectorExecuteChartRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_execute_chart_records", b"connector_execute_chart_records"]) -> None: ...

global___ListConnectorExecuteChartRecordsResponse = ListConnectorExecuteChartRecordsResponse



# generated by datamodel-codegen:
#   filename:  airbyte_definitions.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional


class AuthType(Enum):
    OAuth2_0 = 'OAuth2.0'


@dataclass
class Field0:
    access_token: str
    refresh_token: str
    auth_type: Optional[AuthType] = AuthType.OAuth2_0
    client_id: Optional[str] = None
    client_secret: Optional[str] = None



# generated by datamodel-codegen:
#   filename:  huggingface_task_token_classification_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    end: Optional[int] = None
    entity_group: Optional[str] = None
    score: Optional[float] = None
    start: Optional[int] = None
    word: Optional[str] = None


@dataclass
class Output:
    results: List[Result]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#vdp/pipeline/v1beta/connector.proto\x12\x13vdp.pipeline.v1beta\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\"\xb8\n\n\tConnector\x12/\n\x04name\x18\x01 \x01(\tB\x1b\x92\x41\x14\xca>\x11\xfa\x02\x0e\x63onnector_name\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12i\n\x19\x63onnector_definition_name\x18\x04 \x01(\tB-\xe2\x41\x01\x05\xfa\x41&\n$api.instill.tech/ConnectorDefinitionR\x17\x63onnectorDefinitionName\x12<\n\x04type\x18\x05 \x01(\x0e\x32\".vdp.pipeline.v1beta.ConnectorTypeB\x04\xe2\x41\x01\x03R\x04type\x12+\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x43\n\rconfiguration\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\rconfiguration\x12@\n\x05state\x18\t \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateB\x04\xe2\x41\x01\x03R\x05state\x12\"\n\ttombstone\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x41\n\x0b\x63reate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12O\n\nvisibility\x18\x0f \x01(\x0e\x32).vdp.pipeline.v1beta.Connector.VisibilityB\x04\xe2\x41\x01\x03R\nvisibility\x12\x61\n\x14\x63onnector_definition\x18\x10 \x01(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionB\x04\xe2\x41\x01\x03R\x13\x63onnectorDefinition\x12\x41\n\x0b\x64\x65lete_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12#\n\nowner_name\x18\x12 \x01(\tB\x04\xe2\x41\x01\x03R\townerName\x12\x39\n\x05owner\x18\x14 \x01(\x0b\x32\x17.core.mgmt.v1beta.OwnerB\x05\xe2\x41\x02\x01\x03H\x01R\x05owner\x88\x01\x01\"S\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\x12\x16\n\x12VIEW_CONFIGURATION\x10\x03\"\\\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12STATE_DISCONNECTED\x10\x01\x12\x13\n\x0fSTATE_CONNECTED\x10\x02\x12\x0f\n\x0bSTATE_ERROR\x10\x03\"W\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x16\n\x12VISIBILITY_PRIVATE\x10\x01\x12\x15\n\x11VISIBILITY_PUBLIC\x10\x02:B\xea\x41?\n\x1a\x61pi.instill.tech/Connector\x12\x0f\x63onnectors/{id}\x12\x10\x63onnectors/{uid}B\x0e\n\x0c_descriptionB\x08\n\x06_ownerJ\x04\x08\x13\x10\x14\"\xc0\x02\n\x15ListConnectorsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\x9f\x01\n\x16ListConnectorsResponse\x12>\n\nconnectors\x18\x01 \x03(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\nconnectors\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xce\x01\n\x16LookUpConnectorRequest\x12g\n\tpermalink\x18\x01 \x01(\tBI\x92\x41#\xca> \xfa\x02\x1doperator_definition_permalink\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\tpermalink\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"W\n\x17LookUpConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xa9\x01\n\x1a\x43reateUserConnectorRequest\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\x12M\n\x06parent\x18\x02 \x01(\tB5\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1a\x61pi.instill.tech/ConnectorR\x06parent\"[\n\x1b\x43reateUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\x93\x03\n\x19ListUserConnectorsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12M\n\x06parent\x18\x05 \x01(\tB5\x92\x41\x0f\xca>\x0c\xfa\x02\tuser_name\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1a\x61pi.instill.tech/ConnectorR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xa3\x01\n\x1aListUserConnectorsResponse\x12>\n\nconnectors\x18\x01 \x03(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\nconnectors\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xbb\x01\n\x17GetUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"X\n\x18GetUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xa3\x01\n\x1aUpdateUserConnectorRequest\x12\x42\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorB\x04\xe2\x41\x01\x02R\tconnector\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"[\n\x1bUpdateUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"q\n\x1a\x44\x65leteUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"\x1d\n\x1b\x44\x65leteUserConnectorResponse\"r\n\x1b\x43onnectUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"\\\n\x1c\x43onnectUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"u\n\x1e\x44isconnectUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"_\n\x1f\x44isconnectUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xa1\x01\n\x1aRenameUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12.\n\x10new_connector_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0enewConnectorId\"[\n\x1bRenameUserConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xb7\x01\n\x1b\x45xecuteUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x12\n\x04task\x18\x03 \x01(\tR\x04task\"Q\n\x1c\x45xecuteUserConnectorResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\"o\n\x18TestUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"W\n\x19TestUserConnectorResponse\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateR\x05state\"p\n\x19WatchUserConnectorRequest\x12S\n\x04name\x18\x01 \x01(\tB?\x92\x41\x19\xca>\x16\xfa\x02\x13user_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"X\n\x1aWatchUserConnectorResponse\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateR\x05state\"\xb9\x01\n\"CreateOrganizationConnectorRequest\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\x12U\n\x06parent\x18\x02 \x01(\tB=\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1a\x61pi.instill.tech/ConnectorR\x06parent\"c\n#CreateOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xa3\x03\n!ListOrganizationConnectorsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12U\n\x06parent\x18\x05 \x01(\tB=\x92\x41\x17\xca>\x14\xfa\x02\x11organization_name\xe2\x41\x01\x02\xfa\x41\x1c\x12\x1a\x61pi.instill.tech/ConnectorR\x06parent\x12,\n\x0cshow_deleted\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xab\x01\n\"ListOrganizationConnectorsResponse\x12>\n\nconnectors\x18\x01 \x03(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\nconnectors\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xcb\x01\n\x1fGetOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"`\n GetOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xab\x01\n\"UpdateOrganizationConnectorRequest\x12\x42\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorB\x04\xe2\x41\x01\x02R\tconnector\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"c\n#UpdateOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\x81\x01\n\"DeleteOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"%\n#DeleteOrganizationConnectorResponse\"\x82\x01\n#ConnectOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"d\n$ConnectOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\x85\x01\n&DisconnectOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"g\n\'DisconnectOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xb1\x01\n\"RenameOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12.\n\x10new_connector_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x0enewConnectorId\"c\n#RenameOrganizationConnectorResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\"\xc7\x01\n#ExecuteOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\x12/\n\x06inputs\x18\x02 \x03(\x0b\x32\x17.google.protobuf.StructR\x06inputs\x12\x12\n\x04task\x18\x03 \x01(\tR\x04task\"Y\n$ExecuteOrganizationConnectorResponse\x12\x31\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x07outputs\"\x7f\n TestOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"_\n!TestOrganizationConnectorResponse\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateR\x05state\"\x80\x01\n!WatchOrganizationConnectorRequest\x12[\n\x04name\x18\x01 \x01(\tBG\x92\x41!\xca>\x1e\xfa\x02\x1borganization_connector_name\xe2\x41\x01\x02\xfa\x41\x1c\n\x1a\x61pi.instill.tech/ConnectorR\x04name\"`\n\"WatchOrganizationConnectorResponse\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateR\x05state\"\xc5\x02\n\x1aListConnectorsAdminRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12\x42\n\x04view\x18\x03 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x02R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x03R\x06\x66ilter\x88\x01\x01\x12,\n\x0cshow_deleted\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01H\x04R\x0bshowDeleted\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filterB\x0f\n\r_show_deleted\"\xa4\x01\n\x1bListConnectorsAdminResponse\x12>\n\nconnectors\x18\x01 \x03(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\nconnectors\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x8e\x01\n\x1bLookUpConnectorAdminRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32#.vdp.pipeline.v1beta.Connector.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"\\\n\x1cLookUpConnectorAdminResponse\x12<\n\tconnector\x18\x01 \x01(\x0b\x32\x1e.vdp.pipeline.v1beta.ConnectorR\tconnector\";\n\x15\x43heckConnectorRequest\x12\"\n\tpermalink\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\tpermalink\"T\n\x16\x43heckConnectorResponse\x12:\n\x05state\x18\x01 \x01(\x0e\x32$.vdp.pipeline.v1beta.Connector.StateR\x05stateB\xdd\x01\n\x17\x63om.vdp.pipeline.v1betaB\x0e\x43onnectorProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\016ConnectorProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _CONNECTOR.fields_by_name['name']._options = None
  _CONNECTOR.fields_by_name['name']._serialized_options = b'\222A\024\312>\021\372\002\016connector_name\342A\001\003'
  _CONNECTOR.fields_by_name['uid']._options = None
  _CONNECTOR.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['id']._options = None
  _CONNECTOR.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _CONNECTOR.fields_by_name['connector_definition_name']._options = None
  _CONNECTOR.fields_by_name['connector_definition_name']._serialized_options = b'\342A\001\005\372A&\n$api.instill.tech/ConnectorDefinition'
  _CONNECTOR.fields_by_name['type']._options = None
  _CONNECTOR.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['description']._options = None
  _CONNECTOR.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _CONNECTOR.fields_by_name['configuration']._options = None
  _CONNECTOR.fields_by_name['configuration']._serialized_options = b'\342A\001\002'
  _CONNECTOR.fields_by_name['state']._options = None
  _CONNECTOR.fields_by_name['state']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['tombstone']._options = None
  _CONNECTOR.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['create_time']._options = None
  _CONNECTOR.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['update_time']._options = None
  _CONNECTOR.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['visibility']._options = None
  _CONNECTOR.fields_by_name['visibility']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['connector_definition']._options = None
  _CONNECTOR.fields_by_name['connector_definition']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['delete_time']._options = None
  _CONNECTOR.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['owner_name']._options = None
  _CONNECTOR.fields_by_name['owner_name']._serialized_options = b'\342A\001\003'
  _CONNECTOR.fields_by_name['owner']._options = None
  _CONNECTOR.fields_by_name['owner']._serialized_options = b'\342A\002\001\003'
  _CONNECTOR._options = None
  _CONNECTOR._serialized_options = b'\352A?\n\032api.instill.tech/Connector\022\017connectors/{id}\022\020connectors/{uid}'
  _LISTCONNECTORSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTORSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTORSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSREQUEST.fields_by_name['view']._options = None
  _LISTCONNECTORSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTORSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTCONNECTORSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LOOKUPCONNECTORREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPCONNECTORREQUEST.fields_by_name['permalink']._serialized_options = b'\222A#\312> \372\002\035operator_definition_permalink\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _LOOKUPCONNECTORREQUEST.fields_by_name['view']._options = None
  _LOOKUPCONNECTORREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _CREATEUSERCONNECTORREQUEST.fields_by_name['parent']._options = None
  _CREATEUSERCONNECTORREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\034\022\032api.instill.tech/Connector'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['view']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['parent']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\017\312>\014\372\002\tuser_name\342A\001\002\372A\034\022\032api.instill.tech/Connector'
  _LISTUSERCONNECTORSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTUSERCONNECTORSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _GETUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _GETUSERCONNECTORREQUEST.fields_by_name['view']._options = None
  _GETUSERCONNECTORREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEUSERCONNECTORREQUEST.fields_by_name['connector']._options = None
  _UPDATEUSERCONNECTORREQUEST.fields_by_name['connector']._serialized_options = b'\342A\001\002'
  _UPDATEUSERCONNECTORREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERCONNECTORREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _DELETEUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _CONNECTUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _CONNECTUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _DISCONNECTUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _DISCONNECTUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _RENAMEUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _RENAMEUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _RENAMEUSERCONNECTORREQUEST.fields_by_name['new_connector_id']._options = None
  _RENAMEUSERCONNECTORREQUEST.fields_by_name['new_connector_id']._serialized_options = b'\342A\001\002'
  _EXECUTEUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _EXECUTEUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _TESTUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _TESTUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _WATCHUSERCONNECTORREQUEST.fields_by_name['name']._options = None
  _WATCHUSERCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A\031\312>\026\372\002\023user_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _CREATEORGANIZATIONCONNECTORREQUEST.fields_by_name['parent']._options = None
  _CREATEORGANIZATIONCONNECTORREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\034\022\032api.instill.tech/Connector'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['parent']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['parent']._serialized_options = b'\222A\027\312>\024\372\002\021organization_name\342A\001\002\372A\034\022\032api.instill.tech/Connector'
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['show_deleted']._options = None
  _LISTORGANIZATIONCONNECTORSREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _GETORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _GETORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _GETORGANIZATIONCONNECTORREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONCONNECTORREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _UPDATEORGANIZATIONCONNECTORREQUEST.fields_by_name['connector']._options = None
  _UPDATEORGANIZATIONCONNECTORREQUEST.fields_by_name['connector']._serialized_options = b'\342A\001\002'
  _UPDATEORGANIZATIONCONNECTORREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONCONNECTORREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _DELETEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _CONNECTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _CONNECTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _DISCONNECTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _DISCONNECTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _RENAMEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _RENAMEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _RENAMEORGANIZATIONCONNECTORREQUEST.fields_by_name['new_connector_id']._options = None
  _RENAMEORGANIZATIONCONNECTORREQUEST.fields_by_name['new_connector_id']._serialized_options = b'\342A\001\002'
  _EXECUTEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _EXECUTEORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _TESTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _TESTORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _WATCHORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._options = None
  _WATCHORGANIZATIONCONNECTORREQUEST.fields_by_name['name']._serialized_options = b'\222A!\312>\036\372\002\033organization_connector_name\342A\001\002\372A\034\n\032api.instill.tech/Connector'
  _LISTCONNECTORSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTORSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTORSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSADMINREQUEST.fields_by_name['view']._options = None
  _LISTCONNECTORSADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSADMINREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTORSADMINREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORSADMINREQUEST.fields_by_name['show_deleted']._options = None
  _LISTCONNECTORSADMINREQUEST.fields_by_name['show_deleted']._serialized_options = b'\342A\001\001'
  _LOOKUPCONNECTORADMINREQUEST.fields_by_name['permalink']._options = None
  _LOOKUPCONNECTORADMINREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _LOOKUPCONNECTORADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPCONNECTORADMINREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _CHECKCONNECTORREQUEST.fields_by_name['permalink']._options = None
  _CHECKCONNECTORREQUEST.fields_by_name['permalink']._serialized_options = b'\342A\001\002'
  _globals['_CONNECTOR']._serialized_start=343
  _globals['_CONNECTOR']._serialized_end=1679
  _globals['_CONNECTOR_VIEW']._serialized_start=1313
  _globals['_CONNECTOR_VIEW']._serialized_end=1396
  _globals['_CONNECTOR_STATE']._serialized_start=1398
  _globals['_CONNECTOR_STATE']._serialized_end=1490
  _globals['_CONNECTOR_VISIBILITY']._serialized_start=1492
  _globals['_CONNECTOR_VISIBILITY']._serialized_end=1579
  _globals['_LISTCONNECTORSREQUEST']._serialized_start=1682
  _globals['_LISTCONNECTORSREQUEST']._serialized_end=2002
  _globals['_LISTCONNECTORSRESPONSE']._serialized_start=2005
  _globals['_LISTCONNECTORSRESPONSE']._serialized_end=2164
  _globals['_LOOKUPCONNECTORREQUEST']._serialized_start=2167
  _globals['_LOOKUPCONNECTORREQUEST']._serialized_end=2373
  _globals['_LOOKUPCONNECTORRESPONSE']._serialized_start=2375
  _globals['_LOOKUPCONNECTORRESPONSE']._serialized_end=2462
  _globals['_CREATEUSERCONNECTORREQUEST']._serialized_start=2465
  _globals['_CREATEUSERCONNECTORREQUEST']._serialized_end=2634
  _globals['_CREATEUSERCONNECTORRESPONSE']._serialized_start=2636
  _globals['_CREATEUSERCONNECTORRESPONSE']._serialized_end=2727
  _globals['_LISTUSERCONNECTORSREQUEST']._serialized_start=2730
  _globals['_LISTUSERCONNECTORSREQUEST']._serialized_end=3133
  _globals['_LISTUSERCONNECTORSRESPONSE']._serialized_start=3136
  _globals['_LISTUSERCONNECTORSRESPONSE']._serialized_end=3299
  _globals['_GETUSERCONNECTORREQUEST']._serialized_start=3302
  _globals['_GETUSERCONNECTORREQUEST']._serialized_end=3489
  _globals['_GETUSERCONNECTORRESPONSE']._serialized_start=3491
  _globals['_GETUSERCONNECTORRESPONSE']._serialized_end=3579
  _globals['_UPDATEUSERCONNECTORREQUEST']._serialized_start=3582
  _globals['_UPDATEUSERCONNECTORREQUEST']._serialized_end=3745
  _globals['_UPDATEUSERCONNECTORRESPONSE']._serialized_start=3747
  _globals['_UPDATEUSERCONNECTORRESPONSE']._serialized_end=3838
  _globals['_DELETEUSERCONNECTORREQUEST']._serialized_start=3840
  _globals['_DELETEUSERCONNECTORREQUEST']._serialized_end=3953
  _globals['_DELETEUSERCONNECTORRESPONSE']._serialized_start=3955
  _globals['_DELETEUSERCONNECTORRESPONSE']._serialized_end=3984
  _globals['_CONNECTUSERCONNECTORREQUEST']._serialized_start=3986
  _globals['_CONNECTUSERCONNECTORREQUEST']._serialized_end=4100
  _globals['_CONNECTUSERCONNECTORRESPONSE']._serialized_start=4102
  _globals['_CONNECTUSERCONNECTORRESPONSE']._serialized_end=4194
  _globals['_DISCONNECTUSERCONNECTORREQUEST']._serialized_start=4196
  _globals['_DISCONNECTUSERCONNECTORREQUEST']._serialized_end=4313
  _globals['_DISCONNECTUSERCONNECTORRESPONSE']._serialized_start=4315
  _globals['_DISCONNECTUSERCONNECTORRESPONSE']._serialized_end=4410
  _globals['_RENAMEUSERCONNECTORREQUEST']._serialized_start=4413
  _globals['_RENAMEUSERCONNECTORREQUEST']._serialized_end=4574
  _globals['_RENAMEUSERCONNECTORRESPONSE']._serialized_start=4576
  _globals['_RENAMEUSERCONNECTORRESPONSE']._serialized_end=4667
  _globals['_EXECUTEUSERCONNECTORREQUEST']._serialized_start=4670
  _globals['_EXECUTEUSERCONNECTORREQUEST']._serialized_end=4853
  _globals['_EXECUTEUSERCONNECTORRESPONSE']._serialized_start=4855
  _globals['_EXECUTEUSERCONNECTORRESPONSE']._serialized_end=4936
  _globals['_TESTUSERCONNECTORREQUEST']._serialized_start=4938
  _globals['_TESTUSERCONNECTORREQUEST']._serialized_end=5049
  _globals['_TESTUSERCONNECTORRESPONSE']._serialized_start=5051
  _globals['_TESTUSERCONNECTORRESPONSE']._serialized_end=5138
  _globals['_WATCHUSERCONNECTORREQUEST']._serialized_start=5140
  _globals['_WATCHUSERCONNECTORREQUEST']._serialized_end=5252
  _globals['_WATCHUSERCONNECTORRESPONSE']._serialized_start=5254
  _globals['_WATCHUSERCONNECTORRESPONSE']._serialized_end=5342
  _globals['_CREATEORGANIZATIONCONNECTORREQUEST']._serialized_start=5345
  _globals['_CREATEORGANIZATIONCONNECTORREQUEST']._serialized_end=5530
  _globals['_CREATEORGANIZATIONCONNECTORRESPONSE']._serialized_start=5532
  _globals['_CREATEORGANIZATIONCONNECTORRESPONSE']._serialized_end=5631
  _globals['_LISTORGANIZATIONCONNECTORSREQUEST']._serialized_start=5634
  _globals['_LISTORGANIZATIONCONNECTORSREQUEST']._serialized_end=6053
  _globals['_LISTORGANIZATIONCONNECTORSRESPONSE']._serialized_start=6056
  _globals['_LISTORGANIZATIONCONNECTORSRESPONSE']._serialized_end=6227
  _globals['_GETORGANIZATIONCONNECTORREQUEST']._serialized_start=6230
  _globals['_GETORGANIZATIONCONNECTORREQUEST']._serialized_end=6433
  _globals['_GETORGANIZATIONCONNECTORRESPONSE']._serialized_start=6435
  _globals['_GETORGANIZATIONCONNECTORRESPONSE']._serialized_end=6531
  _globals['_UPDATEORGANIZATIONCONNECTORREQUEST']._serialized_start=6534
  _globals['_UPDATEORGANIZATIONCONNECTORREQUEST']._serialized_end=6705
  _globals['_UPDATEORGANIZATIONCONNECTORRESPONSE']._serialized_start=6707
  _globals['_UPDATEORGANIZATIONCONNECTORRESPONSE']._serialized_end=6806
  _globals['_DELETEORGANIZATIONCONNECTORREQUEST']._serialized_start=6809
  _globals['_DELETEORGANIZATIONCONNECTORREQUEST']._serialized_end=6938
  _globals['_DELETEORGANIZATIONCONNECTORRESPONSE']._serialized_start=6940
  _globals['_DELETEORGANIZATIONCONNECTORRESPONSE']._serialized_end=6977
  _globals['_CONNECTORGANIZATIONCONNECTORREQUEST']._serialized_start=6980
  _globals['_CONNECTORGANIZATIONCONNECTORREQUEST']._serialized_end=7110
  _globals['_CONNECTORGANIZATIONCONNECTORRESPONSE']._serialized_start=7112
  _globals['_CONNECTORGANIZATIONCONNECTORRESPONSE']._serialized_end=7212
  _globals['_DISCONNECTORGANIZATIONCONNECTORREQUEST']._serialized_start=7215
  _globals['_DISCONNECTORGANIZATIONCONNECTORREQUEST']._serialized_end=7348
  _globals['_DISCONNECTORGANIZATIONCONNECTORRESPONSE']._serialized_start=7350
  _globals['_DISCONNECTORGANIZATIONCONNECTORRESPONSE']._serialized_end=7453
  _globals['_RENAMEORGANIZATIONCONNECTORREQUEST']._serialized_start=7456
  _globals['_RENAMEORGANIZATIONCONNECTORREQUEST']._serialized_end=7633
  _globals['_RENAMEORGANIZATIONCONNECTORRESPONSE']._serialized_start=7635
  _globals['_RENAMEORGANIZATIONCONNECTORRESPONSE']._serialized_end=7734
  _globals['_EXECUTEORGANIZATIONCONNECTORREQUEST']._serialized_start=7737
  _globals['_EXECUTEORGANIZATIONCONNECTORREQUEST']._serialized_end=7936
  _globals['_EXECUTEORGANIZATIONCONNECTORRESPONSE']._serialized_start=7938
  _globals['_EXECUTEORGANIZATIONCONNECTORRESPONSE']._serialized_end=8027
  _globals['_TESTORGANIZATIONCONNECTORREQUEST']._serialized_start=8029
  _globals['_TESTORGANIZATIONCONNECTORREQUEST']._serialized_end=8156
  _globals['_TESTORGANIZATIONCONNECTORRESPONSE']._serialized_start=8158
  _globals['_TESTORGANIZATIONCONNECTORRESPONSE']._serialized_end=8253
  _globals['_WATCHORGANIZATIONCONNECTORREQUEST']._serialized_start=8256
  _globals['_WATCHORGANIZATIONCONNECTORREQUEST']._serialized_end=8384
  _globals['_WATCHORGANIZATIONCONNECTORRESPONSE']._serialized_start=8386
  _globals['_WATCHORGANIZATIONCONNECTORRESPONSE']._serialized_end=8482
  _globals['_LISTCONNECTORSADMINREQUEST']._serialized_start=8485
  _globals['_LISTCONNECTORSADMINREQUEST']._serialized_end=8810
  _globals['_LISTCONNECTORSADMINRESPONSE']._serialized_start=8813
  _globals['_LISTCONNECTORSADMINRESPONSE']._serialized_end=8977
  _globals['_LOOKUPCONNECTORADMINREQUEST']._serialized_start=8980
  _globals['_LOOKUPCONNECTORADMINREQUEST']._serialized_end=9122
  _globals['_LOOKUPCONNECTORADMINRESPONSE']._serialized_start=9124
  _globals['_LOOKUPCONNECTORADMINRESPONSE']._serialized_end=9216
  _globals['_CHECKCONNECTORREQUEST']._serialized_start=9218
  _globals['_CHECKCONNECTORREQUEST']._serialized_end=9277
  _globals['_CHECKCONNECTORRESPONSE']._serialized_start=9279
  _globals['_CHECKCONNECTORRESPONSE']._serialized_end=9363
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import artifact.artifact.v1alpha.artifact_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ArtifactPublicServiceStub:
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """

class ArtifactPublicServiceAsyncStub:
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        artifact.artifact.v1alpha.artifact_pb2.LivenessResponse,
    ]
    """Check if the artifact server is alive

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse,
    ]
    """Check if the artifact server is ready

    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """

class ArtifactPublicServiceServicer(metaclass=abc.ABCMeta):
    """Artifact

    ArtifactPublicService exposes the public endpoints that allow clients to
    manage artifacts.
    """

    @abc.abstractmethod
    def Liveness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.LivenessResponse]]:
        """Check if the artifact server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ReadinessResponse]]:
        """Check if the artifact server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """

def add_ArtifactPublicServiceServicer_to_server(servicer: ArtifactPublicServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# generated by datamodel-codegen:
#   filename:  text_task_split_by_token_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List


@dataclass
class Output:
    chunk_num: int
    text_chunks: List[str]
    token_count: int
